<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO\Response\Error;

class Coz02100CustoRealizado extends \Zeedhi\Framework\Controller\Report {
	protected $crudService;
	protected $util;
	protected $dataSourceManager;
	protected $novoCodigo;
	protected $entityManager;
	protected $birtStrategy;
	protected $Coz01000ConsumoPlanejado;

	public function __construct(ReportService $reportService, $crudService, $util, $novoCodigo, $entityManager, $birtStrategy, $Coz01000ConsumoPlanejado) {
		$this->crudService    	= $crudService;
		$this->util             = $util;
		$this->novoCodigo    	= $novoCodigo;
		$this->entityManager    = $entityManager;
		$this->birtStrategy     = $birtStrategy;
		$this->Coz01000ConsumoPlanejado = $Coz01000ConsumoPlanejado;
		
		parent::__construct($reportService);
    }
	
	protected $reportMapping = array (
       'cus02100' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'DTINICIAL'     => 'P_DTINI',
                'DTFINAL'       => 'P_DTFIN',
                'NRLISTA'       => 'P_NRLISTA',
                'CDCENTRAL'     => 'P_CDCENTRAL',
                'CDARVPRODINI'  => 'P_CDPRODINIC',
                'CDARVPRODFIN'  => 'P_CDPRODFINA',
                'ORDENA'        => 'P_ORDENA',
                'CDPICTPROD'    => 'P_CDPICTPROD',
                'CDTIPOCUSTOREA'=> 'P_TIPOCUSTOREAL',
                'NRORG'         => 'P_NRORG'
            )
        ),
        'cus02101' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'DTINICIAL'     => 'P_DTINI',
                'DTFINAL'       => 'P_DTFIN',
                'NRLISTA'       => 'P_NRLISTA',
                'CDCENTRAL'     => 'P_CDCENTRAL',
                'CDARVPRODINI'  => 'P_CDPRODINIC',
                'CDARVPRODFIN'  => 'P_CDPRODFINA',
                'ORDENA'        => 'P_ORDENA',
                'CDPICTPROD'    => 'P_CDPICTPROD',
                'CDTIPOCUSTOREA'=> 'P_TIPOCUSTOREAL',
                'NRORG'         => 'P_NRORG'
            )
        ),
        'cus02102' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'DTINICIAL'     => 'P_DTINI',
                'DTFINAL'       => 'P_DTFIN',
                'NRLISTA'       => 'P_NRLISTA',
                'CDCENTRAL'     => 'P_CDCENTRAL',
                'CDTIPOCUSTOREA'=> 'P_TIPOCUSTOREAL',
                'CDARVPRODINI'  => 'P_CDPRODINIC',
                'CDARVPRODFIN'  => 'P_CDPRODFINA',
                'NRORG'         => 'P_NRORG'
            )
        )
    );
	
	public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response){
	    try {
	        $row = $request->getRow();
    	    if(empty($row['NMSERVFILI'])) $row['NMSERVFILI'] = $this->Coz01000ConsumoPlanejado->filtraServicos($row);
	    	
    	    $row['NRLISTA'] = $this->Coz01000ConsumoPlanejado->gerarListaServ($row['NMSERVFILI'], $row['NRORG']);
    	   // $nrListaConsplan = $this->Coz01000ConsumoPlanejado->gerarLista($row['NMSERVFILI'], $row['NRORG']);
    	   // $row['NRCONSPLAN'] = $this->Coz01000ConsumoPlanejado->gerarNrConsplan($nrListaConsplan, $row);
    	    
    	    $row['CDARVPRODINI'] = empty($row['CDARVPRODINI']) ? '0' : $row['CDARVPRODINI'];
            $row['CDARVPRODFIN'] =  empty($row['CDARVPRODFIN']) ? "Z" : str_pad($row['CDARVPRODFIN'], 10, "Z", STR_PAD_RIGHT);

    	    $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
	    } catch(\Exception $e){
	        $response->setError(new Error($e->getMessage(), 500));
	    }
	}
}